JsonSchemaReader class

A reader for JSON Schema files.

This class provides functionality to read and parse JSON Schema files (Draft 7 format) into structured Dart objects for easy programmatic access.

Constructors

JsonSchemaReader()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseSchemaFromString(String jsonString) JsonSchema
Parses a JSON Schema from a JSON string.
readSchema(String filePath) Future<JsonSchema>
Reads and parses a JSON Schema file from the given filePath.
readSchemaSync(String filePath) JsonSchema
Synchronously reads and parses a JSON Schema file from the given filePath.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited